import * as PC from "@pseuco/lang";
import * as PCT from "@pseuco/static-semantics";
import { PCCCompiler } from "./PCCCompiler.js";
import { PCCVariableInfo } from "./PCCProgramController.js";
import { PCCContainer } from "./PCCContainer.js";
export declare class PCCCompileProgramVisitor extends PC.AbstractVisitor<void> {
    readonly compiler: PCCCompiler;
    readonly compilingNodes: Array<PC.Node>;
    constructor(compiler: PCCCompiler, compilingNodes: Array<PC.Node>);
    compileNode(node: PC.Node, context?: unknown): void;
    visitProgram(node: PC.Program): void;
    visitMainAgent(node: PC.MainAgent): void;
    visitProcedureDeclaration(node: PC.ProcedureDeclaration): void;
    visitMonitor(node: PC.Monitor): void;
    visitStruct(node: PC.Struct): void;
    visitConditionDeclaration(node: PC.ConditionDeclaration): void;
    visitVariableDeclarations(node: PC.VariableDeclarations): void;
    visitVariableDeclarator(node: PC.VariableDeclarator): void;
    visitProcedureParameter(node: PC.ProcedureParameter, context?: unknown): void;
    visitVariableInitializer(node: PC.VariableInitializer, context?: unknown): void;
    visitArrayTypeNode(node: PC.ArrayTypeNode, context?: unknown): void;
    visitSimpleTypeNode(node: PC.SimpleTypeNode, context?: unknown): void;
    visitChannelTypeNode(node: PC.ChannelTypeNode, context?: unknown): void;
    visitClassTypeNode(node: PC.ClassTypeNode, context?: unknown): void;
    visitStartExpression(node: PC.StartExpression, context?: unknown): void;
    visitAssignExpression(node: PC.AssignExpression, context?: unknown): void;
    visitAssignDestination(node: PC.AssignDestination, context?: unknown): void;
    visitSendExpression(node: PC.SendExpression, context?: unknown): void;
    visitConditionalExpression(node: PC.ConditionalExpression, context?: unknown): void;
    visitOrExpression(node: PC.OrExpression, context?: unknown): void;
    visitAndExpression(node: PC.AndExpression, context?: unknown): void;
    visitEqualityExpression(node: PC.EqualityExpression, context?: unknown): void;
    visitRelationalExpression(node: PC.RelationalExpression, context?: unknown): void;
    visitAdditiveExpression(node: PC.AdditiveExpression, context?: unknown): void;
    visitMultiplicativeExpression(node: PC.MultiplicativeExpression, context?: unknown): void;
    visitUnaryExpression(node: PC.UnaryExpression, context?: unknown): void;
    visitPostfixExpression(node: PC.PostfixExpression, context?: unknown): void;
    visitReceiveExpression(node: PC.ReceiveExpression, context?: unknown): void;
    visitProcedureCall(node: PC.ProcedureCall, context?: unknown): void;
    visitClassCall(node: PC.ClassCall, context?: unknown): void;
    visitArrayExpression(node: PC.ArrayExpression, context?: unknown): void;
    visitLiteralExpression(node: PC.LiteralExpression, context?: unknown): void;
    visitIdentifierExpression(node: PC.IdentifierExpression, context?: unknown): void;
    visitStatementWrapper(node: PC.StatementWrapper, context?: unknown): void;
    visitBreakStatement(node: PC.BreakStatement, context?: unknown): void;
    visitContinueStatement(node: PC.ContinueStatement, context?: unknown): void;
    visitStatementBlock(node: PC.StatementBlock, context?: unknown): void;
    visitStatementExpression(node: PC.StatementExpression, context?: unknown): void;
    visitSelectStatement(node: PC.SelectStatement, context?: unknown): void;
    visitCase(node: PC.Case, context?: unknown): void;
    visitConditionStatement(node: PC.ConditionStatement, context?: unknown): void;
    visitIfStatement(node: PC.IfStatement, context?: unknown): void;
    visitWhileStatement(node: PC.WhileStatement, context?: unknown): void;
    visitDoStatement(node: PC.DoStatement, context?: unknown): void;
    visitForStatement(node: PC.ForStatement, context?: unknown): void;
    visitForInit(node: PC.ForInit, context?: unknown): void;
    visitReturnStatement(node: PC.ReturnStatement, context?: unknown): void;
    visitPrimitiveStatement(node: PC.PrimitiveStatement, context?: unknown): void;
    visitPrintStatement(node: PC.PrintStatement, context?: unknown): void;
}
export declare class PCCVariableInitialisation {
    static createContainerForPrimitiveType(compiler: PCCCompiler, type: PCT.PrimitiveType): PCCContainer;
    static createContainerForSystemType(compiler: PCCCompiler, type: PCT.SystemType): PCCContainer;
    static createContainerForArrayType(compiler: PCCCompiler, type: PCT.ArrayType, initialElements?: Array<PCCContainer>): import("./PCCContainer.js").PCCVariableContainer;
    static createContainerForChannelType(compiler: PCCCompiler, type: PCT.ChannelType): PCCContainer;
    static createContainerForClassType(compiler: PCCCompiler, type: PCT.ClassType): PCCContainer;
    static typeRequiresCustomDefaultContainer(compiler: PCCCompiler, type: PCT.Type): boolean;
    static createContainerForType(compiler: PCCCompiler, type: PCT.Type): PCCContainer;
    static compileDefaultValue(compiler: PCCCompiler, variable: PCCVariableInfo): PCCContainer;
    static compileVariableInitializer(compiler: PCCCompiler, initializer: PC.VariableInitializer, type: PCT.Type): PCCContainer;
}
