import * as PC from "@pseuco/lang";
import { PCCCompiler } from "./PCCCompiler.js";
import { PCCApplicationPlaceholderStackElement } from "./PCCCompilerStack.js";
import { PCCContainer } from "./PCCContainer.js";
export declare class SelectPreparationData {
    readonly compiler: PCCCompiler;
    readonly selectStatement: PC.SelectStatement;
    private casePrepData?;
    get casePreparationData(): ReadonlyMap<PC.Case, CasePreparationData>;
    get isPrepared(): boolean;
    constructor(compiler: PCCCompiler, selectStatement: PC.SelectStatement);
    prepare(): void;
}
export declare class CasePreparationData {
    readonly compiler: PCCCompiler;
    readonly caseNode: PC.Case;
    channel: PCCContainer;
    valueToSend?: PCCContainer;
    constructor(compiler: PCCCompiler, caseNode: PC.Case);
    protectContainers(): void;
    unprotectContainers(): void;
}
declare enum LoopControlFlowEventType {
    CONTINUE = 0,
    BREAK = 1
}
declare class LoopControlFlowEvent {
    readonly type: LoopControlFlowEventType;
    readonly appPlaceholder: PCCApplicationPlaceholderStackElement;
    constructor(type: LoopControlFlowEventType, appPlaceholder: PCCApplicationPlaceholderStackElement);
    get isBreakEvent(): boolean;
    get isContinueEvent(): boolean;
    static newBreakEvent(appPlaceHolder: PCCApplicationPlaceholderStackElement): LoopControlFlowEvent;
    static newContinueEvent(appPlaceHolder: PCCApplicationPlaceholderStackElement): LoopControlFlowEvent;
}
export declare class PCCCompileStatementsVisitor extends PC.AbstractVisitor<Array<LoopControlFlowEvent>> {
    readonly compiler: PCCCompiler;
    readonly compilingNodes: Array<PC.Node>;
    constructor(compiler: PCCCompiler, compilingNodes: Array<PC.Node>);
    compileNode(node: PC.Statement | PC.StatementWrapper | PC.Case | PC.ForInit, context?: unknown): Array<LoopControlFlowEvent>;
    visitSelectStatement(node: PC.SelectStatement): LoopControlFlowEvent[];
    visitCase(node: PC.Case, context: CasePreparationData | null): LoopControlFlowEvent[];
    visitStatementWrapper(node: PC.StatementWrapper, context?: unknown): LoopControlFlowEvent[];
    visitBreakStatement(node: PC.BreakStatement, context?: unknown): LoopControlFlowEvent[];
    visitContinueStatement(node: PC.ContinueStatement, context?: unknown): LoopControlFlowEvent[];
    visitStatementBlock(node: PC.StatementBlock, context?: unknown): LoopControlFlowEvent[];
    visitStatementExpression(node: PC.StatementExpression, context?: unknown): LoopControlFlowEvent[];
    visitIfStatement(node: PC.IfStatement, context?: unknown): LoopControlFlowEvent[];
    visitWhileStatement(node: PC.WhileStatement, context?: unknown): LoopControlFlowEvent[];
    visitDoStatement(node: PC.DoStatement, context?: unknown): LoopControlFlowEvent[];
    visitForStatement(node: PC.ForStatement, context?: unknown): LoopControlFlowEvent[];
    visitForInit(node: PC.ForInit, context?: unknown): LoopControlFlowEvent[];
    visitReturnStatement(node: PC.ReturnStatement, context?: unknown): LoopControlFlowEvent[];
    visitPrimitiveStatement(node: PC.PrimitiveStatement, context?: unknown): LoopControlFlowEvent[];
    visitConditionStatement(node: PC.ConditionStatement, context?: unknown): LoopControlFlowEvent[];
    visitPrintStatement(node: PC.PrintStatement, context?: unknown): LoopControlFlowEvent[];
    visitProgram(node: PC.Program, context?: unknown): LoopControlFlowEvent[];
    visitMainAgent(node: PC.MainAgent, context?: unknown): LoopControlFlowEvent[];
    visitProcedureDeclaration(node: PC.ProcedureDeclaration, context?: unknown): LoopControlFlowEvent[];
    visitProcedureParameter(node: PC.ProcedureParameter, context?: unknown): LoopControlFlowEvent[];
    visitMonitor(node: PC.Monitor, context?: unknown): LoopControlFlowEvent[];
    visitStruct(node: PC.Struct, context?: unknown): LoopControlFlowEvent[];
    visitConditionDeclaration(node: PC.ConditionDeclaration, context?: unknown): LoopControlFlowEvent[];
    visitVariableDeclarations(node: PC.VariableDeclarations, context?: unknown): LoopControlFlowEvent[];
    visitVariableDeclarator(node: PC.VariableDeclarator, context?: unknown): LoopControlFlowEvent[];
    visitVariableInitializer(node: PC.VariableInitializer, context?: unknown): LoopControlFlowEvent[];
    visitArrayTypeNode(node: PC.ArrayTypeNode, context?: unknown): LoopControlFlowEvent[];
    visitSimpleTypeNode(node: PC.SimpleTypeNode, context?: unknown): LoopControlFlowEvent[];
    visitChannelTypeNode(node: PC.ChannelTypeNode, context?: unknown): LoopControlFlowEvent[];
    visitClassTypeNode(node: PC.ClassTypeNode, context?: unknown): LoopControlFlowEvent[];
    visitStartExpression(node: PC.StartExpression, context?: unknown): LoopControlFlowEvent[];
    visitAssignExpression(node: PC.AssignExpression, context?: unknown): LoopControlFlowEvent[];
    visitAssignDestination(node: PC.AssignDestination, context?: unknown): LoopControlFlowEvent[];
    visitSendExpression(node: PC.SendExpression, context?: unknown): LoopControlFlowEvent[];
    visitConditionalExpression(node: PC.ConditionalExpression, context?: unknown): LoopControlFlowEvent[];
    visitOrExpression(node: PC.OrExpression, context?: unknown): LoopControlFlowEvent[];
    visitAndExpression(node: PC.AndExpression, context?: unknown): LoopControlFlowEvent[];
    visitEqualityExpression(node: PC.EqualityExpression, context?: unknown): LoopControlFlowEvent[];
    visitRelationalExpression(node: PC.RelationalExpression, context?: unknown): LoopControlFlowEvent[];
    visitAdditiveExpression(node: PC.AdditiveExpression, context?: unknown): LoopControlFlowEvent[];
    visitMultiplicativeExpression(node: PC.MultiplicativeExpression, context?: unknown): LoopControlFlowEvent[];
    visitUnaryExpression(node: PC.UnaryExpression, context?: unknown): LoopControlFlowEvent[];
    visitPostfixExpression(node: PC.PostfixExpression, context?: unknown): LoopControlFlowEvent[];
    visitReceiveExpression(node: PC.ReceiveExpression, context?: unknown): LoopControlFlowEvent[];
    visitProcedureCall(node: PC.ProcedureCall, context?: unknown): LoopControlFlowEvent[];
    visitClassCall(node: PC.ClassCall, context?: unknown): LoopControlFlowEvent[];
    visitArrayExpression(node: PC.ArrayExpression, context?: unknown): LoopControlFlowEvent[];
    visitLiteralExpression(node: PC.LiteralExpression, context?: unknown): LoopControlFlowEvent[];
    visitIdentifierExpression(node: PC.IdentifierExpression, context?: unknown): LoopControlFlowEvent[];
}
export {};
