import { CCSType } from "./PCCProgramController.js";
import * as CCS from "@pseuco/ccs-interpreter";
export declare abstract class PCCContainer {
    readonly ccsType: CCSType;
    constructor(ccsType: CCSType);
    abstract isReadonly(): boolean;
    abstract ccsTree(): CCS.CCSExpression;
    abstract isEqual(container: PCCContainer): boolean;
}
export declare class PCCConstantContainer extends PCCContainer {
    readonly value: string | boolean | number;
    constructor(value: string | boolean | number);
    isReadonly(): boolean;
    ccsTree(): CCS.CCSConstantExpression;
    isEqual(container: PCCContainer): boolean;
}
export declare class PCCVariableContainer extends PCCContainer {
    readonly identifier: string;
    constructor(identifier: string, ccsType: CCSType);
    isReadonly(): boolean;
    ccsTree(): CCS.CCSVariableExpression;
    isEqual(container: PCCContainer): boolean;
}
export type PCCBinaryContainerOperator = "==" | "!=" | "<" | ">" | "<=" | ">=" | "+" | "-" | "*" | "/" | "%" | "^" | "&&" | "||";
export declare class PCCBinaryContainer extends PCCContainer {
    readonly leftContainer: PCCContainer;
    readonly rightContainer: PCCContainer;
    readonly operator: PCCBinaryContainerOperator;
    private _ccsTree;
    constructor(leftContainer: PCCContainer, rightContainer: PCCContainer, operator: PCCBinaryContainerOperator);
    isReadonly(): boolean;
    ccsTree(): CCS.CCSExpression;
    isEqual(container: PCCContainer): boolean;
}
export declare class PCCUnaryContainer extends PCCContainer {
    readonly operator: "!" | "-" | "+";
    readonly container: PCCContainer;
    private _ccsTree;
    constructor(operator: "!" | "-" | "+", container: PCCContainer);
    isReadonly(): boolean;
    ccsTree(): CCS.CCSExpression;
    isEqual(container: PCCContainer): boolean;
}
